@@ -4,4 +4,4 @@ flake8-postponed-annotations package.
 Checks for literal string usage in type annotations
 """
 
-plugin_prefix = 'PEA'
+plugin_prefix = 'PAE'
